#
# spec file for package ghc-tls
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name tls
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.3.11
Release:        8.9
Summary:        TLS/SSL protocol native implementation (Server and Client)
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-asn1-encoding-devel
BuildRequires:  ghc-asn1-types-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cereal-devel
BuildRequires:  ghc-cryptonite-devel
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-memory-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-x509-devel
BuildRequires:  ghc-x509-store-devel
BuildRequires:  ghc-x509-validation-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hourglass-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
Native Haskell TLS and SSL protocol implementation for server and client.

This provides a high-level implementation of a sensitive security protocol,
eliminating a common set of security issues through the use of the advanced
type system, high level constructions and common Haskell features.

Currently implement the SSL3.0, TLS1.0, TLS1.1 and TLS1.2 protocol, and support
RSA and Ephemeral (Elliptic curve and regular) Diffie Hellman key exchanges,
and many extensions.

Some debug tools linked with tls, are available through the
<http://hackage.haskell.org/package/tls-debug/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri Jun 30 2017 psimons@suse.com
- Update to version 1.3.11.
* Wed Apr 26 2017 psimons@suse.com
- Update to version 1.3.10 revision 2 with cabal2obs.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 1.3.10 revision 1 with cabal2obs.
* Wed Jan 18 2017 psimons@suse.com
- Update to version 1.3.9 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.3.8 revision 0 with cabal2obs.
* Fri May 13 2016 mimi.vx@gmail.com
- update to 1.3.8
* Wed May 11 2016 mimi.vx@gmail.com
- update to 1.3.7
  * Disable SHA384 based cipher, as they don't work properly yet.
* Sun May  8 2016 mimi.vx@gmail.com
- update to 1.3.6
  * Add new ciphers
  * Improve some debugging and outputs
* Sun Apr 10 2016 mimi.vx@gmail.com
- update to 1.3.5
  * Fix a bug with ECDHE based cipher where serialization
  * Improve tests
  * Debugging: Add a way to print random seed and a way to side-load
    a seed for replayability
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 1.3.4
  * Add support for Hans (Haskell Network Stack)
  * Add support for ECDSA signature
  * Add support for ECDSA-ECDHE Cipher
  * Improve parsing of ECC related structure
* Mon Aug 31 2015 mimi.vx@gmail.com
- update to 1.3.2
  * Add cipher suites for forward secrecy on more clients (Aaron Friel)
  * Maintain more handshake information to be queried by protocol (Adam Wick)
  * handle SCSV on client and server side (Kazu Yamamoto)
  * Cleanup renegotiation logic (Kazu Yamamoto)
  * Various testing improvements with the openssl test parts
  * Cleanup AEAD handling for future support of other ciphers
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to 1.3.1
  * Repair DHE RSA handling on the cipher by creating signature properly
  * modernize the crypto stack by using cryptonite.
* Sun Jun 21 2015 mimi.vx@gmail.com
- update to 1.2.18
  * add more tests (network, local)
  * cleanup cipher / bulk code, certificate verify / creation, and digitall signed handling
  * fix handling of DHE ciphers with MS SSL stack that serialize leading zero.
* Thu Apr 23 2015 mimi.vx@gmail.com
- update to 1.2.17
  * Fix an issue with stream cipher not correctly calculating the internal state,
    resulting systematically in bad record mac failure during handshake
  * support chain certificate in credentials
  * adding ALPN extension
  * adding support for AEAD, and particularly AES128-GCM
  * Adding support for ECDH
  * Do not support SSL3 by default for security reason.
  * add EnumSafe8 and 16 for specific sized Enum instance that are safer
  * export signatureAndHash parser/encoder
  * add a "known" list of extensions
  * add SignatureAlgorithms extension
  * add Heartbeat extension
  * add support for EC curves and point format extensions
  * add preliminary SessionTicket extension
  * Propagate asynchronous exception
  * Export TLSParams and HasBackend type names
  * Added FlexibleContexts flag required by ghc-7.9
  * debug: add support for specifying the timeout length in milliseconds.
  * debug: add support for 3DES in simple client
  * add support for 3DES-EDE-CBC-SHA1 (cipher 0xa)
  * repair retrieve certificate validation, and improve fingerprints
  * remove groom from dependency
  * make RecordM an instance of Applicative
  * Fixes the Error_EOF partial pattern match error in exception handling
  * Fixed socket backend endless loop when the server does not close connection
    properly at the TLS level with the close notify alert.
  * Catch Error_EOF in recvData and return empty data.
  * Fixed Server key exchange data being parsed without the correct
    context, leading to not knowing how to parse the structure.
    The bug happens on efficient server that happens to send the ServerKeyXchg
    message together with the ServerHello in the same handshake packet.
    This trigger parsing of all the messages without having set the pending cipher.
    Delay parsing, when this happen, until we know what to do with it.
  * Fixed unrecognized name non-fatal alert after client hello.
  * Add SSL3 to the supported list of version by default.
  * Fixed handshake records not being able to span multiples records.
* Mon Oct  7 2013 sbahling@suse.com
- Initial package - version 1.1.5
